@@ -27,12 +27,12 @@ pd.options.display.max_columns = 10
 ##############################################
 ### Parameters
 
-base_dir = os.path.split(os.path.realpath(os.path.dirname(__file__)))[0]
-
-with open(os.path.join(base_dir, 'parameters.yml')) as param:
-    param = yaml.safe_load(param)
-
-remotes_list = param['remotes']
+# base_dir = os.path.split(os.path.realpath(os.path.dirname(__file__)))[0]
+#
+# with open(os.path.join(base_dir, 'parameters.yml')) as param:
+#     param = yaml.safe_load(param)
+#
+# remotes_list = param['remotes']
 
 ##############################################
 ### Class
@@ -113,6 +113,7 @@ class Tethys(object):
 
             stn_obj = stn_resp.pop('Body')
             stn_list = read_json_zstd(stn_obj.read())
+            stn_list = [s for s in stn_list if isinstance(s, dict)]
 
             self._stations.update({dataset_id: {s['station_id']: s for s in stn_list}})
 
@@ -296,7 +297,7 @@ class Tethys(object):
 # dataset_id = '9e1a03dc379cbf7037b0873d'
 # site_id = '5c3848a5b9acee6694714e7e'
 #
-# self = Tethys()
+# self = Tethys([remotes_list[0]])
 # self = Tethys(remotes_list)
 #
 # stn_list1 = self.get_stations(dataset_id)
@@ -307,3 +308,24 @@ class Tethys(object):
 # data1 = self.get_time_series_results(dataset_id, station_id, from_date='2012-01-02 00:00', output='Dataset')
 
 # data2 = self.bulk_time_series_results(dataset_id, station_ids, output='DataArray')
+
+# dataset_id = 'f4cfb5a362707785dd39ff85'
+# station_id = 'ff4213c61878e098e07df513'
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
